@@ -12,7 +12,8 @@ import os
 @click.option('-p', '--password', 'password', hide_input=True)
 @click.option('-l', '--local', is_flag=True)
 @click.option('-r', '--repo-name')
-def init(ctx, user_name, password,local, repo_name):
+@click.option('--ssh', is_flag=True)
+def init(ctx, user_name, password,local, repo_name, ssh):
     "Create git repo and github remote"
     if is_initialized_repo():
         click.echo('This is already a git repo!')
@@ -44,7 +45,10 @@ def init(ctx, user_name, password,local, repo_name):
                 click.echo('Repo name already used!')
     else:
         local_repo = init_local_repo()
-        local_repo.create_remote('origin', remote_repo.clone_url)
+        if ssh:
+            local_repo.create_remote('origin', remote_repo.ssh_url)
+        else:
+            local_repo.create_remote('origin', remote_repo.clone_url)
         click.echo('Push to origin...')
         local_repo.git.push('-u', 'origin', 'master')
         click.echo('Ready!')
