@@ -29,7 +29,11 @@ def save(ctx, message, local):
             click.echo("No changes in local repository since last commit")
 
         if not local:
-            if repo.remotes.origin.exists():
+            try: 
+                repo.remotes.origin.exists()
+            except:
+                click.echo('Remote repository does not exist!')
+            else: 
                 try:
                     repo.git.pull()
                 except :
@@ -44,8 +48,6 @@ def save(ctx, message, local):
                     click.echo('Pushing to remote repository...')
                     repo.git.push()
                     click.echo('Done!')
-            else:
-                click.echo('Remote repository does not exist!')
     else:
         click.echo('Please fix the following conflicts then use "gt save" again')
         for conflicted_file in conflicted_files:
